const { app, BrowserWindow, ipcMain, session } = require('electron');

app.commandLine.appendSwitch('ignore-certificate-errors');

function createWindow() {
  const win = new BrowserWindow({
    width: 800,
    height: 600,
    webPreferences: {
      nodeIntegration: true,
      contextIsolation: false,
      enableRemoteModule: true,
    },
  });
  session.defaultSession.clearCache()
  win.maximize(); 
  win.loadFile('login.html');
}

app.whenReady().then(createWindow);

app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit();
  }
});

app.on('activate', () => {
  if (BrowserWindow.getAllWindows().length === 0) {
    createWindow();
  }
});

ipcMain.on('download-file', async (event, url) => {
  try {
    const response = await axios({
      url,
      method: 'GET',
      responseType: 'stream',
      headers: { 'shve-authentication': token },
    });

    const filePath = path.join(__dirname, 'filename');
    const writer = fs.createWriteStream(filePath);

    response.data.pipe(writer);

    writer.on('finish', () => {
      console.log('Download Finished');
    });

    writer.on('error', (error) => {
      console.error('There was an error downloading the file', error);
    });
  } catch (error) {
    console.error('There was an error making the request', error);
  }
});

ipcMain.on('open-interactive-window', (event, sessionID, ip, proxyPort, serverPort, token) => {
  const interactiveWin = new BrowserWindow({
    width: 800,
    height: 600,
    webPreferences: {
      nodeIntegration: true,
      contextIsolation: false,
    },
  });

  const proxyConfig = {
    proxyRules: ip + ':' + proxyPort,
    proxyBypassRules: 'ipapi.co',
  };  

  interactiveWin.webContents.session.webRequest.onBeforeSendHeaders((details, callback) => {
    details.requestHeaders['SHVE'] = sessionID;
    details.requestHeaders['shve-authentication'] = token;
    callback({ cancel: false, requestHeaders: details.requestHeaders });
  });

  interactiveWin.webContents.session.setProxy(proxyConfig).then(() => {
    interactiveWin.loadFile('interactive.html').then(() => {
      interactiveWin.maximize();
      interactiveWin.webContents.executeJavaScript(`document.title = "Session: ${sessionID}";`);
    });
  });
});

ipcMain.on('open-visual-window', (event, sessionID, ip, proxyPort, serverPort, token) => {
  const visualWin = new BrowserWindow({
    width: 800,
    height: 600,
    webPreferences: {
      nodeIntegration: true,
      contextIsolation: false,
    },
  });

  const proxyConfig = {
    proxyRules: ip + ':' + proxyPort,
    proxyBypassRules: 'ipapi.co',
  };  
  
  visualWin.webContents.session.webRequest.onBeforeSendHeaders((details, callback) => {
    details.requestHeaders['SHVE'] = sessionID;
    details.requestHeaders['shve-authentication'] = token;
    callback({ cancel: false, requestHeaders: details.requestHeaders });
  });

  visualWin.webContents.session.setProxy(proxyConfig).then(() => {
    visualWin.loadFile('visual.html').then(() => {
      visualWin.maximize();
      visualWin.webContents.executeJavaScript(`document.title = "Session: ${sessionID}";`);
    });
  });
});